==> chatic-0.0.17.tgz: package/README.md <==
<p align="center">
    <img src="https://storage.googleapis.com/chatic-assets/logo.svg"/>
    <h1 align="center">Chatic Command Line Tool</h1>
    <h5 align="center">Tool for chatbot end-to-end testing</h5>
</p>

<p align="center">
  <a href="https://npmjs.org/package/chatic">
    <img src="https://img.shields.io/npm/v/chatic.svg" alt="NPM Version"/>
  </a>

  <a href="https://github.com/Chatic/chatic-cli/issues">
    <img src="https://img.shields.io/github/issues/Chatic/chatic-cli.svg" alt="Github Issues"/>
  </a>


  <a href="https://travis-ci.org/Chatic/chatic-cli">
    <img src="https://img.shields.io/travis/Chatic/chatic-cli.svg" alt="Travis Status"/>
  </a>


  <a href="https://david-dm.org/Chatic/chatic-cli">
    <img src="https://david-dm.org/Chatic/chatic-cli.svg" alt="dependencies status"/>
  </a>

  <a href="https://david-dm.org/Chatic/chatic-cli?type=dev">
    <img src="https://david-dm.org/Chatic/chatic-cli/dev-status.svg" alt="devDependencies status"/>
  </a>
</p>

## Try it now

If you like what you see, let's go forward and [schedule a demo](https://docs.google.com/forms/d/e/1FAIpQLSfkCxtHC_bElpXFI5bJ24wbPoG9ZCWGnoLyW0aWnFw43L3GCA/viewform?c=0&w=1)

## Install

Chatic is available as an npm module.

```sh
npm i -g chatic
```

## Setup

```sh
chatic init
```

<img src="https://storage.googleapis.com/chatic-assets/Screen%20Shot%202017-01-03%20at%2018.55.13.png" />

## Usage

Run:

```sh
chatic test -src=./test/.chaticconf
```

Host, path to tests, platforms and test framework options can be customized using `.chaticconf` file:

```javascript
{
    "host": "https://demo.chatic.io",
    "tests": "./test/**/*.js",
    "platforms": ["facebook", "slack"],
    "mocha": {
        // Mocha config here
    }
}
```

## API

Inside test case you have access to global variable `chatic`.

### connect
search idle node and bind to current session

```javascript
chatic.connect():Promise
```

### disconnect
method changes current node's status to idle. Also node changes own status after 1 min of inactivity

```javascript
chatic.disconnect():Promise
```

### send
send text and wait for response

```javascript
chatic.send(text:string, delay:number):Promise
```

delay (optional) - set a timer to delay collect of response. Useful if bot answers in several messages

### click
fire click on the button

```javascript
chatic.click(button:string):Promise
```

button - title of the button

### environment
current platform ('facebook', 'slack', etc)

```javascript
chatic.environment
``` 

## Currently support

Platforms 

<img src="https://storage.googleapis.com/chatic-assets/facebook-messenger.svg" />
<img src="https://storage.googleapis.com/chatic-assets/slack-1.svg" />

Frameworks

<img src="https://storage.googleapis.com/chatic-assets/mocha.svg" />

## Author

Chatic Team

<table>
  <tbody>
    <tr>
      <td align="center" width="150">
          <img width="150 height="150"
                src="https://avatars0.githubusercontent.com/u/706387?v=3">
            <a href="https://github.com/katsgeorgeek">
                George
            </a>
      </td>
      <td align="center" width="150">
          <img width="150 height="150"
                src="https://avatars2.githubusercontent.com/u/20769754?v=3">
            <a href="https://github.com/andreybelitsky">
                Andrey
            </a>
      </td>
    <tr>
  <tbody>
</table>

hello@chatic.io

https://chatic.io

==> chatic-0.0.18.tgz: package/README.md <==
<p align="center">
    <img src="https://storage.googleapis.com/chatic-assets/logo.svg"/>
    <h1 align="center">Chatic Command Line Tool</h1>
    <h5 align="center">Tool for chatbot end-to-end testing</h5>
</p>

<p align="center">
  <a href="https://npmjs.org/package/chatic">
    <img src="https://img.shields.io/npm/v/chatic.svg" alt="NPM Version"/>
  </a>

  <a href="https://github.com/Chatic/chatic-cli/issues">
    <img src="https://img.shields.io/github/issues/Chatic/chatic-cli.svg" alt="Github Issues"/>
  </a>


  <a href="https://travis-ci.org/Chatic/chatic-cli">
    <img src="https://img.shields.io/travis/Chatic/chatic-cli.svg" alt="Travis Status"/>
  </a>


  <a href="https://david-dm.org/Chatic/chatic-cli">
    <img src="https://david-dm.org/Chatic/chatic-cli.svg" alt="dependencies status"/>
  </a>

  <a href="https://david-dm.org/Chatic/chatic-cli?type=dev">
    <img src="https://david-dm.org/Chatic/chatic-cli/dev-status.svg" alt="devDependencies status"/>
  </a>
</p>

## Try it now

If you like what you see, let's go forward and [schedule a demo](https://docs.google.com/forms/d/e/1FAIpQLSfkCxtHC_bElpXFI5bJ24wbPoG9ZCWGnoLyW0aWnFw43L3GCA/viewform?c=0&w=1)

## Install

Chatic is available as an npm module.

```sh
npm i -g chatic
```

## Setup

```sh
chatic init
```

<img src="https://storage.googleapis.com/chatic-assets/Screen%20Shot%202017-01-03%20at%2018.55.13.png" />

## Usage

Run:

```sh
chatic test -src=./test/.chaticconf
```

Host, path to tests, platforms and test framework options can be customized using `.chaticconf` file:

```javascript
{
    "host": "https://chatic.io",
    "tests": "./test/**/*.js",
    "platforms": ["facebook", "slack"],
    "mocha": {
        // Mocha config here
    }
}
```

## API

Inside test case you have access to global variable `chatic`.

### connect
search idle node and bind to current session

```javascript
chatic.connect():Promise
```

### disconnect
method changes current node's status to idle. Also node changes own status after 1 min of inactivity

```javascript
chatic.disconnect():Promise
```

### send
send text and wait for response

```javascript
chatic.send(text:string, delay:number):Promise
```

delay (optional) - set a timer to delay collect of response. Useful if bot answers in several messages

### click
fire click on the button

```javascript
chatic.click(button:string):Promise
```

button - title of the button

### environment
current platform ('facebook', 'slack', etc)

```javascript
chatic.environment
```

## Currently support

Platforms

<img src="https://storage.googleapis.com/chatic-assets/facebook-messenger.svg" />
<img src="https://storage.googleapis.com/chatic-assets/slack-1.svg" />

Frameworks

<img src="https://storage.googleapis.com/chatic-assets/mocha.svg" />

## Author

Chatic Team

<table>
  <tbody>
    <tr>
      <td align="center" width="150">
          <img width="150 height="150"
                src="https://avatars0.githubusercontent.com/u/706387?v=3">
            <a href="https://github.com/katsgeorgeek">
                George
            </a>
      </td>
      <td align="center" width="150">
          <img width="150 height="150"
                src="https://avatars2.githubusercontent.com/u/20769754?v=3">
            <a href="https://github.com/andreybelitsky">
                Andrey
            </a>
      </td>
    <tr>
  <tbody>
</table>

hello@chatic.io

https://chatic.io
